@@ -18,6 +18,9 @@ def extract_domain_name(subdomain):
 def _handle_pattern(subdomain):
     end_result = ''
     result = re.search(r'^(.*)\(([a-z.|]+)\)', subdomain)
+    if result is None:
+        # false positive
+        return _extract_single_domain_name(subdomain)
     prefix = result.group(1)
     postfixes = result.group(2).split('|')
     for postfix in postfixes:
